@@ -51,10 +51,10 @@ struct _ZathuraDatabaseInterface
 
   bool (*get_fileinfo)(ZathuraDatabase* db, const char* file, zathura_fileinfo_t* file_info);
 
-  girara_list_t* (*get_recent_files)(ZathuraDatabase* db, int max);
+  girara_list_t* (*get_recent_files)(ZathuraDatabase* db, int max, const char* basepath);
 };
 
-GType zathura_database_get_type(void);
+GType zathura_database_get_type(void) G_GNUC_CONST;
 
 /**
  * Add or update bookmark in the database.
@@ -138,7 +138,7 @@ bool zathura_db_get_fileinfo(zathura_database_t* db, const char* file,
  * limit is applied.
  * @return list of files
  */
-girara_list_t* zathura_db_get_recent_files(zathura_database_t* db, int max);
+girara_list_t* zathura_db_get_recent_files(zathura_database_t* db, int max, const char* basepath);
 
 
 #endif // DATABASE_H
