@@ -119,8 +119,7 @@ zathura_document_open(zathura_t* zathura, const char* path, const char* uri,
   document->uri         = g_strdup(uri);
   if (document->uri == NULL) {
     document->basename    = g_file_get_basename(file);
-  }
-  else {
+  } else {
     GFile *gf = g_file_new_for_uri(document->uri);
     document->basename = g_file_get_basename(gf);
     g_object_unref(gf);
@@ -422,16 +421,15 @@ zathura_document_set_rotation(zathura_document_t* document, unsigned int rotatio
     return;
   }
 
-  document->rotate = rotation % 360;
-
-  if (document->rotate > 0 && document->rotate <= 90) {
-    document->rotate = 90;
-  } else if (document->rotate > 0 && document->rotate <= 180) {
-    document->rotate = 180;
-  } else if (document->rotate > 0 && document->rotate <= 270) {
-    document->rotate = 270;
-  } else {
+  rotation = rotation % 360;
+  if (rotation == 0 || rotation > 270) {
     document->rotate = 0;
+  } else if (rotation <= 90) {
+    document->rotate = 90;
+  } else if (rotation <= 180) {
+    document->rotate = 180;
+  } else {
+    document->rotate = 270;
   }
 }
 
