@@ -5,6 +5,7 @@
 
 #include <stdbool.h>
 #include <girara/types.h>
+#include <girara/session.h>
 #include <gtk/gtk.h>
 #ifdef GDK_WINDOWING_X11
 #include <gtk/gtkx.h>
@@ -12,6 +13,7 @@
 #include "macros.h"
 #include "types.h"
 #include "jumplist.h"
+#include "file-monitor.h"
 
 enum {
   NEXT,
@@ -177,9 +179,7 @@ struct zathura_s
    * File monitor
    */
   struct {
-    GFileMonitor* monitor; /**< File monitor */
-    GFile* file; /**< File for file monitor */
-    gchar* file_path; /**< Save file path */
+    ZathuraFileMonitor* monitor; /**< File monitor */
     gchar* password; /**< Save password */
   } file_monitor;
 
